@@ -30,7 +30,7 @@ if(getRversion() >= "3.5")
 #' @seealso \itemize{
 #' \item \code{\link{AQSys.default}}
 #' \item \code{\link{AQSys.plot}}
-#' \item \code{\link{AQSys.tielines}}
+#' \item \code{\link{AQSys.LevArmRule}}
 #' \item \code{\link{AQSysOthmer}}
 #' \item \code{\link{AQSysBancroft}}
 #' }
@@ -45,6 +45,8 @@ AQSys <- function(dataSET, ...)
 #' @param modelName - Character String specifying the nonlinear empirical equation to fit data.
 #' The default method uses Merchuk's equation. Other mathematical descriptors can be listed using AQSysList().
 #' @param dataSET - Binodal Experimental data that will be used in the nonlinear fit
+#' @param Order Defines how the data is organized in the Worksheet. Use "xy" whether the first column corresponds to the lower phase fraction and "yx" whether the opposite.
+# ' @param maxiter	- A positive integer specifying the maximum number of iterations allowed.
 #' @param ... Additional optional arguments. None are used at present.
 #' @method AQSys default
 #' @export
@@ -74,11 +76,11 @@ AQSys <- function(dataSET, ...)
 # XUEQIAO, X.  et al. Measurement and Correlation of the Phase Diagram Data for PPG400 + (K3PO4, K2CO3, and K2HPO4) + H2O Aqueous Two-Phase Systems at T = 298.15 K. Journal of Chemical & Engineering Data, v. 55, n. 11, p. 4741-4745, 2010/11/11 2010. ISSN 0021-9568. 
 # (\href{https://pubs.acs.org/doi/full/10.1021/je100356s?src=recsys}{ACS Publications})
 # 
-# XIE, X.  et al. Liquidb liquid equilibrium of aqueous two-phase systems of PPG400 and biodegradable salts at temperatures of (298.15, 308.15, and 318.15) K. Journal of Chemical & Engineering Data, v. 55, n. 8, p. 2857-2861,  2010. ISSN 0021-9568. 
+# XIE, X.  et al. Liquidb-liquid equilibrium of aqueous two-phase systems of PPG400 and biodegradable salts at temperatures of (298.15, 308.15, and 318.15) K. Journal of Chemical & Engineering Data, v. 55, n. 8, p. 2857-2861,  2010. ISSN 0021-9568. 
 # (\href{https://pubs.acs.org/doi/abs/10.1021/je901019t}{ACS Publications})
-AQSys.default <- function(dataSET, modelName = "merchuk", ...) {
+AQSys.default <- function(dataSET, modelName = "merchuk", Order="xy", ...) {
   # arrange data and guarantee R converted it to numbers but dont switch columns to prevent incompatibility with pre-existent functions 
-  dataSET <- toNumeric(dataSET, "xy")
+  dataSET <- toNumeric(dataSET, Order)
   # each switch option calls a correspondent equation to fit dataSET
   # equations are functions declared in AQSysFormulas.R
   if (modelName %in% names(AQSysList(TRUE))) {
@@ -103,7 +105,6 @@ AQSys.default <- function(dataSET, modelName = "merchuk", ...) {
 #' @param xlbl Plot's Horizontal axis label.
 #' @param ylbl Plot's Vertical axis label.
 #' @param main Legacy from plot package. For more details, see \code{\link{plot.default}}
-#' 
 #' @param col Legacy from plot package. For more details, see \code{\link{plot.default}}
 #' @param type Legacy from plot package. For more details, see \code{\link{plot.default}}
 #' @param cex Legacy from plot package. For more details, see \code{\link{plot.default}}
@@ -111,13 +112,12 @@ AQSys.default <- function(dataSET, modelName = "merchuk", ...) {
 #' @param cexaxis Legacy from plot package. For more details, see \code{\link{plot.default}}
 #' @param cexmain Legacy from plot package. For more details, see \code{\link{plot.default}}
 #' @param cexsub Legacy from plot package. For more details, see \code{\link{plot.default}}
-#' 
 #' @param modelName - Character String specifying the nonlinear empirical equation to fit data. The default method uses
 #' Merchuk's equation. Other possibilities can be seen in AQSysList().
 #' @param NP Number of points used to build the fitted curve. Default is 100. [type:Integer]
 #' @param xmax Maximum value for the Horizontal axis' value
 #' @param ymax Maximum value for the Vertical axis' value
-#' @param colDis Defines how the data is organized in the Worksheet. Use "xy" whether the first column corresponds to the lower phase fraction and "yx" whether the opposite.
+#' @param Order Defines how the data is organized in the Worksheet. Use "xy" whether the first column corresponds to the lower phase fraction and "yx" whether the opposite.
 #' @param save Save the generated plot in the disk using path and filename provided by the user. [type:Boulean]
 #' @param HR Adjust Plot's text to be compatible with High Resolution size [type:Boulean]
 #' @param filename Filename provided by the user to save a given plot. [type:String]
@@ -132,29 +132,29 @@ AQSys.default <- function(dataSET, modelName = "merchuk", ...) {
 #' #
 #' AQSys.plot(dataSET)
 #' #
-AQSys.plot <-
-  function  (dataSET,
-             xlbl = "",
-             ylbl = "",
-             main = NULL,
-             col = "blue",
-             type = "p",
-             cex = 1,
-             cexlab = 1,
-             cexaxis = 1,
-             cexmain = 1,
-             cexsub = 1,
-             modelName = "merchuk",
-             NP = 100,
-             xmax = "",
-             ymax = "",
-             colDis = "xy",
-             save = FALSE,
-             HR = FALSE,
-             filename = NULL,
-             wdir = NULL,
-             silent = FALSE,
-             ...)
+AQSys.plot <- function  (dataSET,
+                         xlbl = "",
+                         ylbl = "",
+                         main = NULL,
+                         col = "blue",
+                         type = "p",
+                         cex = 1,
+                         cexlab = 1,
+                         cexaxis = 1,
+                         cexmain = 1,
+                         cexsub = 1,
+                         modelName = "merchuk",
+                         NP = 100,
+                         xmax = "",
+                         ymax = "",
+                         Order = "xy",
+                         save = FALSE,
+                         HR = FALSE,
+                         filename = NULL,
+                         wdir = NULL,
+                         silent = FALSE,
+                         ...
+)
   {
     #
     plot_image = NULL
@@ -166,12 +166,12 @@ AQSys.plot <-
       ylbl <- names(dataSET)[2]
     }
     # guarantee all lines are valid (non-na and numeric)
-    dataSET <- toNumeric(dataSET, colDis)
+    dataSET <- toNumeric(dataSET, Order)
     # Calculate aesthetically better xmax and ymax
-    if ((xmax == "") | (xmax > 1) | (xmax < round(max(dataSET[1]) / 0.92, 1))) {
+    if ((xmax == "") | ((xmax > 1) & (max(dataSET[1]) <= 1)) | ((xmax > 100) & (max(dataSET[1]) <= 100) & (max(dataSET[1]) >= 10)) | (xmax < round(max(dataSET[1]) / 0.92, 1))) {
       xmax <- ceiling(round(max(dataSET[1]) / 0.92, 1)/5)*5
     }
-    if ((ymax == "") | (ymax > 1) | (ymax < round(max(dataSET[2]) / 0.92, 1))) {
+    if ((ymax == "") | ((ymax > 1) & (max(dataSET[2]) <= 1)) | ((ymax > 100) & (max(dataSET[2]) <= 100) & (max(dataSET[2]) >= 1)) | (ymax < round(max(dataSET[2]) / 0.92, 1))) {
       ymax <- ceiling(round(max(dataSET[2]) / 0.92, 1)/5)*5
     }
     # If save=TRUE adjust variables and parameters to save plot
@@ -211,7 +211,7 @@ AQSys.plot <-
       ) +
       scale_y_continuous(
         expand = c(0, 0),
-        limits = c(0.001, ymax),
+        limits = c(-0.5, ymax),
         breaks = seq(0, ymax, by = 5),
         labels = seq(0, ymax, by = 5)
       ) +
@@ -223,15 +223,18 @@ AQSys.plot <-
       )
     #
     # add curve generated using regression parameters
-    rawdt <- data.frame(dataSET[1], Fn(CoefSET, dataSET[1]))
-    names(rawdt) <- c("XC", "YC")
+    # print(rbind(dataSET[1], xmax))
+    # Xs <- ifelse(((xmax != "") & (is.numeric(xmax)) & (xmax != max(dataSET[1]))), rbind(dataSET[1], xmax), dataSET[1])
+    Xs <- as.data.frame(ifelse((xmax != max(dataSET[1])), rbind(dataSET[1], xmax), dataSET[1]))
+    rawdt <- setNames(data.frame(Xs, Fn(CoefSET, Xs)), c("XC", "YC"))
+    #
     plot_image <-
       plot_image + geom_line(
         data = rawdt,
         aes_string(x = "XC", y = "YC"),
         color = "red",
-        linetype = 2,
-        size = 1.1
+        linetype = "solid",
+        size = 1
       )
     #
     if (save == TRUE) {
